@@ -2,19 +2,36 @@
 Tools for tracking peaks in later sweeps based on peaks in earlier sweeps.
 """
 
-from . import live_fitting as lf
+import PySimpleGUI as sg
+import numpy as np
+from lorentzian_models import models
+
+from . import automatic
 from . import fit_lorentz as fl
+from . import live_fitting as lf
 from . import sliding_window as sw
 from . import utilities as util
-from . import automatic
-from lorentzian_models import models
-import numpy as np
-import PySimpleGUI as sg
+
 
 def find_last_peak(params_3d, index):
     """
     Finds the parameters for the last time a given Lorentzian wasn't a nan
     array.
+
+    Parameters
+    ----------
+    params_3d : arr
+        3D Lorentzian parameter array.
+    index : int
+        Index corresponding to the 2D Lorentzian parameter array to extract the
+        last peak from.
+
+    Returns
+    -------
+    arr
+        1D Lorentzian parameter array for the last peak from the chosen index.
+    arr
+        Array with the number of recursion steps.
     """
     # print(params_3d)
     if not any(np.isnan(params_3d[-1][index])):
@@ -35,6 +52,18 @@ def get_reference_params(params_3d):
     """
     Finds the last usable parameters for a complete 2d Lorentzian parameter
     array.
+
+    Parameters
+    ----------
+    params_3d : arr
+        3D Lorentzian parameter array.
+
+    Returns
+    -------
+    arr
+        2D Lorentzian parameter array.
+    arr
+        Step count.
     """
     reference_params_2d = np.empty((0, 4))
     step_count = np.empty((0, 1))
@@ -49,6 +78,20 @@ def get_reference_params(params_3d):
 def find_min_f(f, active_params, active_index):
     """
     Finds lowest f that doesn't intersect another Lorentzian.
+
+    Parameters
+    ----------
+    f : arr
+        1D array of frequencies.
+    active_params : arr
+        Lorentzian parameter array corresponding to the given frequency array.
+    active_index : int
+        Recursion index.
+
+    Returns
+    -------
+    float
+        Minimum frequency.
     """
     if active_index == 0:
         return min(f)
@@ -62,6 +105,20 @@ def find_min_f(f, active_params, active_index):
 def find_max_f(f, active_params, active_index):
     """
     Finds greatest f that doesn't intersect another Lorentzian.
+
+    Parameters
+    ----------
+    f : arr
+        1D array of frequencies.
+    active_params : arr
+        Lorentzian parameter array corresponding to the given frequency array.
+    active_index : int
+        Recursion index.
+
+    Returns
+    -------
+    float
+        Minimum frequency.
     """
     if active_index == len(active_params) - 1:
         return max(f)
@@ -75,6 +132,20 @@ def find_max_f(f, active_params, active_index):
 def find_extremes_f(f, active_params, active_index):
     """
     Finds values for an f region that doesn't intersect other Lorentzians.
+
+    Parameters
+    ----------
+    f : arr
+        1D array of frequencies.
+    active_params : arr
+        Lorentzian parameter array corresponding to the given frequency array.
+    active_index : int
+        Recursion index.
+
+    Returns
+    -------
+    float
+        Minimum frequency.
     """
     f1 = find_min_f(f, active_params, active_index)
     f2 = find_max_f(f, active_params, active_index)
@@ -84,6 +155,29 @@ def find_extremes_f(f, active_params, active_index):
 
 
 def recursive_split(model, f, v, regions, base_zoom, limit=None):
+    """
+    Split regions recursively.
+
+    Parameters
+    ----------
+    model : model
+        Model to use.
+    f : arr
+        1D frequency array.
+    v : arr
+        1D amplitude (voltage) array.
+    regions : arr
+        Regions array.
+    base_zoom : float
+        Zoom level to recursively split over.
+    limit : float
+        The zoom limit level that ends the recursive splitting.
+
+    Returns
+    -------
+    arr
+        Recursively split regions.
+    """
     if limit is None:
         limit = base_zoom - 2
     if base_zoom > 0:
@@ -110,6 +204,19 @@ def find_missing_peaks_sep(
     """
     Uses machine learning to search within a given frequency space for missing
     Lorentzians.
+
+    Parameters
+    ----------
+    f : arr
+        1D frequency array.
+    v : arr
+        1D amplitude (voltage) array.
+    active_params : arr
+        Lorentzian parameter array.
+    reference_params : arr
+        Lorentzian parameter array.
+    search_limit : float
+        Multiplicative factor saying how far out to search.
     """
     updated_params = np.empty((0, 4))
     noise_level = 3 * sw.extract_noise(f)
@@ -327,11 +434,9 @@ def track_temperatures(
     if print_params:
         print('Initial Parameters: ')
         print(initial_params)
-    # print(depth)
     for i in util._progressbar(
             range(start_index + 1, start_index + depth),
             'Processing: '):
-        # try:
         if progress_window:
             sg.one_line_progress_meter(
                 'Overall Fitting Progress', i - start_index, depth, '-key-')
@@ -344,16 +449,10 @@ def track_temperatures(
         active_params = match_params(all_peaks[-1], active_params)
         active_params = util.param_sort(active_params)
         if correction:
-            # print('corection at index ' + str(i))
             active_params = find_missing_peaks(
                 f, v, active_params, reference_params, search_limit)
-            # active_params = match_params(all_peaks[-1], active_params)
             active_params = match_params(reference_params, active_params)
             active_params = util.param_sort(active_params)
-            # print('active_params:')
-            # print(active_params)
-            # print()
-        # active_params = util.param_sort(active_params)
         active_params = util.param_sort(active_params)
         active_params = bind_params(
             reference_params, active_params, reference_counts)
@@ -362,17 +461,10 @@ def track_temperatures(
         if live_display:
             if live is not None:
                 live.close_window()
-            # try:
             live = lf.Live_Instance(f, v)
             live.import_lorentzians(region_params)
             live.activate(loop=False)
-            # except:
-            #     live = lf.Live_Instance(f, v)
-            #     live.activate(loop=False)
-        # print()
-        # print()
         if any(np.isnan(region_params.flatten())):
-            # print(region_params)
             region_params = util.remove_nans(region_params)
         previous_regions = fl.regions_from_parameters(
             data_files[i].f, region_params)
@@ -493,8 +585,6 @@ def match_params(reference_params, target_params):
     updated_params : arr
         2D Lorentzian parameter array. Revised version of target_params.
     """
-    # reference_params is a 2d Lorentzian parameter array
-    # target_params is a 2d Lorentzian parameter array
     ref_invert = False
     if len(target_params) > len(reference_params):
         reference_params, target_params = target_params, reference_params
@@ -519,7 +609,6 @@ def match_params(reference_params, target_params):
         np.argsort(match_array.ravel()), match_shape))[0]
     num_matched = 0
     k_best = 0
-    # print(best_vals)
     while num_matched < len(target_params):
         indices = best_vals[k_best]
         i = indices[0]
@@ -527,12 +616,6 @@ def match_params(reference_params, target_params):
         if update_match(reference_list, target_list, i, j):
             num_matched += 1
         k_best += 1
-        # print('reference list:')
-        # print(reference_list)
-        # print('target list:')
-        # print(target_list)
-        # print()
-        # print(num_matched)
     if ref_invert:
         updated_params = get_updated_target(target_list, reference_list)
     else:
@@ -588,8 +671,6 @@ def final_sorting(params_3d):
     final_params = np.array([params_3d[0]])
     for i in range(1, len(params_3d)):
         reference_params, counts = get_reference_params(params_3d[0:i])
-        # print('got got')
-        # print(reference_params)
         target_params = params_3d[i]
         matched_params = match_params(reference_params, target_params)
         combined_params = np.append(
