@@ -2,16 +2,38 @@
 Framework for passive model training scripts.
 """
 
-from . import utilities as util
-from . import efficient_data_generation as ed
-from . import classify_data as cd
+import os
+
 import numpy as np
 import tensorflow as tf
-import os
+
+from . import classify_data as cd
+from . import efficient_data_generation as ed
+from . import utilities as util
+
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 
 
 def set_default(parameter, default, num_models=1):
+    """
+    Set the default set of parameters to train models off of. Will return the
+    provided parameters unless the array is empty. In that case, will provide
+    the `default` paramters instead.
+
+    Parameters
+    ----------
+    parameter : arr
+        Lorentzian parameter array.
+    default : arr
+        Lorentzian parameter array.
+    num_models : int, optional
+        By default 1.
+
+    Returns
+    -------
+    parameters
+        Lorentzian parameter array.
+    """
     if len(parameter) == 0:
         for i in range(0, num_models):
             parameter.append(default)
@@ -48,6 +70,69 @@ def passive_train(
     """
     Passively trains a model that detects whether or not a Lorentzian is
     present.
+
+    Parameters
+    ----------
+    name : str, optional
+        Model name, by default 'unnamed_model'.
+    location : str, optional
+        Directory to save the model in, by default None.
+    data_size : int, optional
+        Size of data set to use for a batch of training, by default 10000.
+    scale : tuple, optional
+        Three element tuple that defines the scale of data that the model will
+        be looking at, by default (0, 1, 1024). The zeroth element is the
+        minimum value of the Lorentzian. The first value is the maximum. And
+        the second value is the number of elements in the array. This is the
+        default scale throughout `peak_finder` and is standard for normalized
+        Lorentzians.
+    expansion : int, optional
+        How many times the full width at half maximum to extend data outside
+        the Lorentzian, by default 2.
+    noise : bool, optional
+        Whether or not Gaussian noise should be added to the trainign data, by
+        default True.
+    epochs : int, optional
+        Epochs, by default 1000.
+    overwrite : bool, optional
+        Overwrite existing model in save location, by default False.
+    model_design : keras model, optional
+        By default None. This sets up a three layer Sequential model.
+    optimizer : str, optional
+        By default 'Adadelta'.
+    loss : keras loss function, optional
+        by default None. This sets up a sparse categorical crossentropy loss.
+    metrics : list, optional
+        By default ['accuracy'].
+    stop_condition : bool, optional
+        Whether or not the training should stop on its own, by default False.
+    steps : int, optional
+        By default 1.
+    wiggle : int, optional
+        How many times the full width at half maximum to shift the center of
+        the Lorentzian by, defaults to 0.
+    verbose : int, optional
+        By default 1.
+    min_noise_amp : int, optional
+        By default 1.
+    max_noise_amp : int, optional
+        By default 1.
+    min_noise_width : int, optional
+        by default 1.
+    max_noise_width : int, optional
+        By default 1.
+    no_quit : bool, optional
+        By default False.
+    progress : bool, optional
+        By default True.
+    backup : bool, optional
+        By default True.
+    start_n : int, optional
+        By default 0.
+    max_n : [type], optional
+        By default np.inf.
+    split : bool, optional
+        By default False.
     """
     path = os.path.join(location, name)
     backup_path = os.path.join(location, name + '_backup')
@@ -71,6 +156,10 @@ def passive_train(
     n = start_n
 
     def train_routine():
+        """
+        Custom train routine based on the passed parameters to the parent
+        function.
+        """
         try:
             model.save(backup_path)
         except BaseException:
@@ -126,7 +215,7 @@ def passive_train(
                 train_routine()
             except BaseException:
                 n -= 1
-                print('An error occured. Restarting round.')
+                print('An error occurred. Restarting round.')
 
     else:
         while not stop_condition:
@@ -154,8 +243,46 @@ def passive_class_train(
         verbose=1,
         no_quit=False):
     """
-    Passively trains a model that classifies a given Lorentzian cluster as
-    having some number of Lorentzians inside it.
+    Passively trains a model that classifies a given Lorentzian cluster as having some number of Lorentzians inside it.
+
+    Parameters
+    ----------
+    name : str, optional
+        Model name, by default 'unnamed_model'.
+    location : str, optional
+        Directory to save the model in, by default None.
+    data_size : int, optional
+        Size of data set to use for a batch of training, by default 10000.
+    scale : tuple, optional
+        Three element tuple that defines the scale of data that the model will
+        be looking at, by default (0, 1, 1024). The zeroth element is the
+        minimum value of the Lorentzian. The first value is the maximum. And
+        the second value is the number of elements in the array. This is the
+        default scale throughout `peak_finder` and is standard for normalized
+        Lorentzians.
+    noise : bool, optional
+        Whether Gaussian noise should be added to the training data, by
+        default True.
+    epochs : int, optional
+        Epochs, by default 1000.
+    overwrite : bool, optional
+        Overwrite existing model in save location, by default False.
+    model_design : keras model, optional
+        By default None. This sets up a three layer Sequential model.
+    optimizer : str, optional
+        By default 'Adadelta'.
+    loss : keras loss function, optional
+        by default None. This sets up a sparse categorical crossentropy loss.
+    metrics : list, optional
+        By default ['accuracy'].
+    stop_condition : bool, optional
+        Whether the training should stop on its own, by default False.
+    steps : int, optional
+        By default 1.
+    verbose : int, optional
+        By default 1.
+    no_quit : bool, optional
+        By default False.
     """
     path = os.path.join(location, name)
     backup_path = os.path.join(location, name + '_backup')
@@ -194,6 +321,10 @@ def passive_class_train(
         print('No existing data and labels found.')
 
     def train_routine(running_data, running_labels):
+        """
+        Custom train routine based on the passed parameters to the parent
+        function.
+        """
         try:
             model.save(backup_path)
         except BaseException:
@@ -241,9 +372,23 @@ def passive_class_train(
 
 
 def last_n(arr, n=10000):
+    """
+    Safely give the last n elements of the array.
+
+    Parameters
+    ----------
+    arr : arr
+        Array.
+    n : int, optional
+        By default 10000.
+
+    Returns
+    -------
+    arr
+        The truncated array.
+    """
     m = len(arr)
     n = min(n, m)
-    # print(arr)
     if len(arr.shape) == 2:
         return arr[max(m - n, 0):n, :]
     else:
