@@ -2,7 +2,7 @@ __all__ = [
     '_bit_invert',
     '_matplotlib_mac_fix',
     '_progressbar',
-    '_save_file'
+    '_save_file',
     '_scatter_pts',
     '_simplify_regions',
     'append_params_3d',
@@ -26,7 +26,7 @@ __all__ = [
     'import_tdms_dir',
     'import_tdms_file',
     'import_tdms_files',
-    'install_models'
+    'install_models',
     'load_dir',
     'load_file',
     'load_files',
